@@ -404,22 +404,22 @@ void KNutPrefDlg::slotApply() {
 
   // Kicker Icon page
 
-  int stateKIcon;
-  if (m_iconRadioButton1->isChecked()) stateKIcon = KNutDock::pictureKI;
-  else stateKIcon = KNutDock::generalKI;
-  if (m_settingData->typeOfKIcon != stateKIcon) {
-    if (m_iconRadioButton1->isChecked()) m_settingData->typeOfKIcon = KNutDock::pictureKI;
-    if (m_iconRadioButton2->isChecked()) m_settingData->typeOfKIcon = KNutDock::generalKI;
-    changeSetting += ChangeTypeOfKIcon;
+  int stateTDEIcon;
+  if (m_iconRadioButton1->isChecked()) stateTDEIcon = KNutDock::pictureKI;
+  else stateTDEIcon = KNutDock::generalKI;
+  if (m_settingData->typeOfTDEIcon != stateTDEIcon) {
+    if (m_iconRadioButton1->isChecked()) m_settingData->typeOfTDEIcon = KNutDock::pictureKI;
+    if (m_iconRadioButton2->isChecked()) m_settingData->typeOfTDEIcon = KNutDock::generalKI;
+    changeSetting += ChangeTypeOfTDEIcon;
     }
 
-  if (m_settingData->customKIconColor != m_checkBoxCbi->isChecked()) {
-    m_settingData->customKIconColor = m_checkBoxCbi->isChecked();
-    changeSetting += ChangeCustomKIconColor;
+  if (m_settingData->customTDEIconColor != m_checkBoxCbi->isChecked()) {
+    m_settingData->customTDEIconColor = m_checkBoxCbi->isChecked();
+    changeSetting += ChangeCustomTDEIconColor;
     }
 
   if (m_settingData->kIconBackgroundColor != m_BGIButton->color()) {
-    changeSetting += ChangeKIconBColor;
+    changeSetting += ChangeTDEIconBColor;
     m_settingData->kIconBackgroundColor = m_BGIButton->color();  // nastavime barvu pozadi
     }
 
@@ -629,7 +629,7 @@ void KNutPrefDlg::initUps () {
   TQHBoxLayout *upsTopLayout = new TQHBoxLayout( page, 0, spacingHint (),"upsTopLayout" );
 
   // makes box for names of UPS's / Vytvorime box pro jmena UPS-ek
-  m_listBox2 = new KListBox( page, "ListBox2" );
+  m_listBox2 = new TDEListBox( page, "ListBox2" );
   m_listBox2->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, m_listBox2->sizePolicy().hasHeightForWidth() ) );
   m_listBox2->setFrameShape( TQListBox::StyledPanel );
   m_listBox2->setFrameShadow( TQListBox::Sunken );
@@ -717,9 +717,9 @@ void KNutPrefDlg::initDock () {
   typeLayout->addWidget ( m_iconRadioButton1,1,0 );
   typeLayout->addWidget ( m_iconRadioButton2,2,0 );
 
-  if (m_settingData->typeOfKIcon == KNutDock::pictureKI)
+  if (m_settingData->typeOfTDEIcon == KNutDock::pictureKI)
     m_iconRadioButton1->setChecked( true );
-  if (m_settingData->typeOfKIcon == KNutDock::generalKI)
+  if (m_settingData->typeOfTDEIcon == KNutDock::generalKI)
     m_iconRadioButton2->setChecked( true );
 
   infoLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
@@ -736,10 +736,10 @@ void KNutPrefDlg::initDock () {
   colorLayout->addWidget (m_dockBackgroundColorLabel,1,0);
   colorLayout->addWidget (m_BGIButton,1,1);
 
-  m_checkBoxCbi->setChecked(m_settingData->customKIconColor);
+  m_checkBoxCbi->setChecked(m_settingData->customTDEIconColor);
   m_BGIButton->setColor(m_settingData->kIconBackgroundColor);
-//  m_BGIButton->setEnabled(m_prefData->customKIconColor);
-//  m_dockBackgroundColorLabel->setEnabled(m_prefData->customKIconColor);
+//  m_BGIButton->setEnabled(m_prefData->customTDEIconColor);
+//  m_dockBackgroundColorLabel->setEnabled(m_prefData->customTDEIconColor);
 
   if (m_iconRadioButton1->isChecked()) {
     m_iconDockLabel->setEnabled(false);
@@ -749,8 +749,8 @@ void KNutPrefDlg::initDock () {
     }
   else {
     m_iconDockLabel->setEnabled(true);
-    m_BGIButton->setEnabled(m_settingData->customKIconColor);
-    m_dockBackgroundColorLabel->setEnabled(m_settingData->customKIconColor);
+    m_BGIButton->setEnabled(m_settingData->customTDEIconColor);
+    m_dockBackgroundColorLabel->setEnabled(m_settingData->customTDEIconColor);
     }
 
   setTopLayout->addStretch( 20 );
@@ -866,7 +866,7 @@ void KNutPrefDlg::initFonts () {
 
 
 
-  m_fontWidget = new KFontChooser(page,"Font",false);
+  m_fontWidget = new TDEFontChooser(page,"Font",false);
   setFontLayout->addWidget (m_fontWidget ,0);
 
   setTopLayout->addStretch( 20 );
